# `prefect-coiled`

Prefect worker for running deployments and flows on Coiled.

The worker polls a Prefect Cloud work pool for pending flows to be run and then uses Coiled to run the flow in the cloud.

To get started, see [this example](https://github.com/coiled/prefect-worker/blob/main/example/README.md).
